@@ -25,6 +25,7 @@ from .baserawio import (
     BaseRawIO,
     _signal_channel_dtype,
     _signal_stream_dtype,
+    _signal_buffer_dtype,
     _spike_channel_dtype,
     _event_channel_dtype,
 )
@@ -93,6 +94,7 @@ class RawBinarySignalRawIO(BaseRawIO):
                 chan_id = f"{c}"
                 units = ""
                 stream_id = "0"
+                buffer_id = "0"
                 signal_channels.append(
                     (
                         name,
@@ -103,15 +105,18 @@ class RawBinarySignalRawIO(BaseRawIO):
                         self.signal_gain,
                         self.signal_offset,
                         stream_id,
+                        buffer_id,
                     )
                 )
 
         signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
 
-        # one unique stream
+        # one unique stream and buffer
         if signal_channels.size > 0:
-            signal_streams = np.array([("Signals", "0")], dtype=_signal_stream_dtype)
+            signal_buffers = np.array([("Signals", "0")], dtype=_signal_buffer_dtype)
+            signal_streams = np.array([("Signals", "0", "0")], dtype=_signal_stream_dtype)
         else:
+            signal_buffers = np.array([], dtype=_signal_buffer_dtype)
             signal_streams = np.array([], dtype=_signal_stream_dtype)
 
         # No events
@@ -126,6 +131,7 @@ class RawBinarySignalRawIO(BaseRawIO):
         self.header = {}
         self.header["nb_block"] = 1
         self.header["nb_segment"] = [1]
+        self.header["signal_buffers"] = signal_buffers
         self.header["signal_streams"] = signal_streams
         self.header["signal_channels"] = signal_channels
         self.header["spike_channels"] = spike_channels
